<?php

namespace Drupal\Tests\twig_casings\Unit;

use Drupal\twig_casings\Twig\CasingExtension;
use PHPUnit\Framework\TestCase;

/**
 * Unit tests for the Twig Casings module.
 *
 * @group twig_casings
 */
class CasingExtensionTest extends TestCase {

  /**
   * The Twig Casing extension service.
   *
   * @var \Drupal\twig_casings\Twig\CasingExtension
   */
  protected $casingExtension;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->casingExtension = new CasingExtension();
  }

  /**
   * Tests the camelCase filter.
   */
  public function testCamelCase() {
    $this->assertEquals('someStringWithDashesInIt', $this->casingExtension->camelCase('Some-string-with-dashes-in-it'));
    $this->assertEquals('someStringWithSpacesInIt', $this->casingExtension->camelCase('Some string with spaces in it'));
    $this->assertEquals('someStringWithUnderscoresInIt', $this->casingExtension->camelCase('Some_string_with_underscores_in_it'));
  }

  /**
   * Tests the kebabCase filter.
   */
  public function testKebabCase() {
    $this->assertEquals('some-string-with-dashes-in-it', $this->casingExtension->kebabCase('Some-string-with-dashes-in-it'));
    $this->assertEquals('some-string-with-spaces-in-it', $this->casingExtension->kebabCase('Some string with spaces in it'));
    $this->assertEquals('some-string-with-underscores-in-it', $this->casingExtension->kebabCase('Some_string_with_underscores_in_it'));
  }

  /**
   * Tests the pascalCase filter.
   */
  public function testPascalCase() {
    $this->assertEquals('SomeStringWithDashesInIt', $this->casingExtension->pascalCase('Some-string-with-dashes-in-it'));
    $this->assertEquals('SomeStringWithSpacesInIt', $this->casingExtension->pascalCase('Some string with spaces in it'));
    $this->assertEquals('SomeStringWithUnderscoresInIt', $this->casingExtension->pascalCase('Some_string_with_underscores_in_it'));
  }

  /**
   * Tests the snakeCase filter.
   */
  public function testSnakeCase() {
    $this->assertEquals('some_string_with_dashes_in_it', $this->casingExtension->snakeCase('Some-string-with-dashes-in-it'));
    $this->assertEquals('some_string_with_spaces_in_it', $this->casingExtension->snakeCase('Some string with spaces in it'));
    $this->assertEquals('some_string_with_underscores_in_it', $this->casingExtension->snakeCase('Some_string_with_underscores_in_it'));
  }

}
